==> dasu_4.02.jar: edu/northwestern/dasu/measurement/types/ProbeType.java <==
/**
 * Dasu Project
 *
 * File:         ProbeType.java
 * RCS:          $Id$
 * Description:  ProbeType class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Oct 2, 2010 at 8:31:59 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu.measurement
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2010, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */

package edu.northwestern.dasu.measurement.types;


/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The ProbeType class ...
 */

public enum ProbeType implements EventTypeInterface {
	PING(600, 20), 
	TRACEROUTE(600, 20),
	HTTP(600, 20),
	NDT(1,1),
	NDT2(5,1),
	SCRAPE(60,1),
	DNS(2000,20);
	
	private int maxProbesPerHour;
	private int maxProbesPerMin;
	private String type;
	
	ProbeType(int probesPerHour, int probesPerMinute) {
		maxProbesPerHour = probesPerHour;
		maxProbesPerMin = probesPerMinute;
		this.type = this.name();
	}
	
	public int getMaxPerHour() {
		return maxProbesPerHour;
	}
	
	public int getMaxPerMin() {
		return maxProbesPerMin;
	}
	
	public String getType() {
		return type;
	}

	
}

==> dasu_4.11.jar: edu/northwestern/dasu/measurement/types/ProbeType.java <==
/**
 * Dasu Project
 *
 * File:         ProbeType.java
 * RCS:          $Id$
 * Description:  ProbeType class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Oct 2, 2010 at 8:31:59 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu.measurement
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2010, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */

package edu.northwestern.dasu.measurement.types;


/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The ProbeType class ...
 */

public enum ProbeType implements EventTypeInterface {
	PING(600, 20), 
	TRACEROUTE(600, 20),
	HTTP(600, 20),
	NDT(1,1),
	NDT2(5,1),
	SCRAPE(60,1),
	DNS(2000,20);
	
	private int maxProbesPerHour;
	private int maxProbesPerMin;
	private String type;
	
	private ProbeType(int probesPerHour, int probesPerMinute) {
		maxProbesPerHour = probesPerHour;
		maxProbesPerMin = probesPerMinute;
		this.type = this.name();
	}
	
	public int getMaxPerHour() {
		return maxProbesPerHour;
	}
	
	public int getMaxPerMin() {
		return maxProbesPerMin;
	}
	
	public String getType() {
		return type;
	}
	
}
